# encoding: UTF-8
require 'nokogiri'

module Dvla
  module VehicleDetails
    class DataExtractor
      def initialize(html)
        @html = html
      end

      def car_data
        get_data(car_table, car_data_titles)
      end

      def tax_data
        get_data(tax_table, tax_data_titles)
      end

      private 

        def doc
          @doc ||= Nokogiri::HTML(@html)
        end

        def tables
          @tables ||= doc.css("table")
        end

        def car_table
          @car_table ||= tables[0]
        end

        def tax_table
          @tax_table ||= tables[1]
        end

        def get_data(table, titles)
          data = {}
          table.css(".vehicledetailstableright .bodytext").each_with_index do |elem, i|
            data[titles[i]] = elem.text
          end
          data
        end

        def car_data_titles
          ["Date of Liability",
           "Date of First Registration",
           "Year of Manufacture",
           "Cylinder Capacity (cc)",
           "Emissions",
           "Fuel Type",
           "Export Marker",
           "Vehicle Status",
           "Vehicle Colour",
           "Vehicle Type Approval",
           "Vehicle Excise Duty rate for vehicle 6 Months Rate",
           "12 Months Rate"
          ]
        end

        def tax_data_titles
          ["6 Months Rate", "12 Months Rate"]
        end
    end
  end
end
